@@ -113,7 +113,11 @@ KGpgDecrypt::nextLine(const QString& line)
 {
 	const QList<QUrl> &inputFiles = getInputFiles();
 
-	if (!inputFiles.isEmpty()) {
+	if (line == QLatin1String("[GNUPG:] DECRYPTION_OKAY")) {
+		// Assume Gpg decryption was successful even if gpg returns
+		// an error code.
+		decryptSuccess = true;
+	} else if (!inputFiles.isEmpty()) {
 		if (line == QLatin1String("[GNUPG:] BEGIN_DECRYPTION")) {
 			emit statusMessage(i18nc("Status message 'Decrypting <filename>' (operation starts)", "Decrypting %1", inputFiles.at(m_fileIndex).fileName()));
 			emit infoProgress(2 * m_fileIndex + 1, inputFiles.count() * 2);
@@ -125,7 +129,7 @@ KGpgDecrypt::nextLine(const QString& line)
 	} else {
 		if (line.startsWith(QLatin1String("[GNUPG:] PLAINTEXT_LENGTH "))) {
 			bool ok;
-			m_plainLength = line.mid(26).toInt(&ok);
+			m_plainLength = line.midRef(26).toInt(&ok);
 			if (!ok)
 				m_plainLength = -1;
 		} else if (line == QLatin1String("[GNUPG:] BEGIN_DECRYPTION")) {
@@ -137,3 +141,15 @@ KGpgDecrypt::nextLine(const QString& line)
 
 	return KGpgTextOrFileTransaction::nextLine(line);
 }
+
+void
+KGpgDecrypt::finish()
+{
+	if (decryptSuccess) {
+		// Gpg error code is ignored.
+		// https://bugs.kde.org/show_bug.cgi?id=357462
+		setSuccess(TS_OK);
+	} else {
+		KGpgTextOrFileTransaction::finish();
+	}
+}
